==> admin_content_notification-8.x-1.0.tar.gz: admin_content_notification/src/Form/AdminContentNotification.php <==
<?php

namespace Drupal\admin_content_notification\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class AdminContentNotification implements settings for admin notification.
 */
class AdminContentNotification extends ConfigFormBase {

  /**
   * Get the form_id.
   *
   * @inheritDoc
   */
  public function getFormId() {
    return 'admin_content_notification_form';
  }

  /**
   * Build the Form.
   *
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
    $form = array();
    $form['admin_content_notification_content_types'] = array(
      '#type' => 'fieldset',
      '#title' => t('Select the content types'),
      '#description' => t('Choose the content type for which you want to admin notified on content insert.'),
    );
    
    $default_content_types = (\Drupal::config('admin_content_notification.settings')->get('admin_content_notification_node_types')) ? : array();
    $form['admin_content_notification_content_types']['admin_content_notification_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Content types'),
      '#default_value' => $default_content_types,
      '#options' => node_type_get_names(),
    );

    $site_email = \Drupal::config('system.site')->get('mail');
    $admin_content_notification_email = \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email');
    $form['admin_content_notification_email'] = array(
      '#type' => 'email',
      '#title' => t('Email to whom the notification is to be sent'),
      '#default_value' => isset($admin_content_notification_email) ? $admin_content_notification_email : $site_email,
    );

    $form['admin_content_notification_email_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => t('Email Settings'),
    );

    $form['admin_content_notification_email_fieldset']['admin_content_notification_email_subject'] = array(
      '#type' => 'textfield',
      '#title' => t('Configurable email subject'),
      '#default_value' => \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email_subject'),
      '#description' => t('Enter a default subject of the notification email.'),
    );

    $form['admin_content_notification_email_fieldset']['admin_content_notification_email_body'] = array(
      '#type' => 'textarea',
      '#title' => t('Configurable email body'),
      '#default_value' => \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email_body'),
      '#description' => t('Enter the default email template to notify users about new content posted on the site. Use the following tokens: %user_who_posted, %new_content_link'),
    );
    return parent::buildForm($form, $form_state);
  }

  /**
   * Get Editable config names.
   *
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return ['admin_content_notification.settings'];
  }

  /**
   * Add submit handler.
   *
   * @inheritDoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_input_values = $form_state->getUserInput();
    $config = $this->configFactory->getEditable('admin_content_notification.settings');
    $config->set('admin_content_notification_node_types', $user_input_values['admin_content_notification_node_types']);
    $config->set('admin_content_notification_email', $user_input_values['admin_content_notification_email']);
    $config->set('admin_content_notification_email_subject', $user_input_values['admin_content_notification_email_subject']);
    $config->set('admin_content_notification_email_body', $user_input_values['admin_content_notification_email_body']);
    $config->save();
    parent::submitForm($form, $form_state);
  }

}

==> admin_content_notification-8.x-1.2.tar.gz: admin_content_notification/src/Form/AdminContentNotification.php <==
<?php

namespace Drupal\admin_content_notification\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class AdminContentNotification implements settings for admin notification.
 */
class AdminContentNotification extends ConfigFormBase {

  /**
   * Get the form_id.
   *
   * @inheritDoc
   */
  public function getFormId() {
    return 'admin_content_notification_form';
  }

  /**
   * Build the Form.
   *
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
    $form = array();
    $form['admin_content_notification_content_types'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Select the content types'),
      '#description' => $this->t('Choose the content type for which you want to admin notified on content insert.'),
    );
    
    $default_content_types = (\Drupal::config('admin_content_notification.settings')->get('admin_content_notification_node_types')) ? : array();
    $form['admin_content_notification_content_types']['admin_content_notification_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => $this->t('Content types'),
      '#default_value' => $default_content_types,
      '#options' => node_type_get_names(),
    );

    $site_email = \Drupal::config('system.site')->get('mail');
    $admin_content_notification_email = \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email');
    $form['admin_content_notification_email'] = array(
      '#type' => 'email',
      '#title' => $this->t('Email to whom the notification is to be sent'),
      '#default_value' => isset($admin_content_notification_email) ? $admin_content_notification_email : $site_email,
    );

    $form['admin_content_notification_email_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Email Settings'),
    );

    $form['admin_content_notification_email_fieldset']['admin_content_notification_email_subject'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Configurable email subject'),
      '#default_value' => \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email_subject'),
      '#description' => $this->t('Enter a default subject of the notification email.'),
    );

    $form['admin_content_notification_email_fieldset']['admin_content_notification_email_body'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Configurable email body'),
      '#default_value' => \Drupal::config('admin_content_notification.settings')->get('admin_content_notification_email_body'),
      '#description' => $this->t('Enter the default email template to notify users about new content posted on the site. Use the following tokens: %user_who_posted, %new_content_link'),
    );
    return parent::buildForm($form, $form_state);
  }

  /**
   * Get Editable config names.
   *
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return ['admin_content_notification.settings'];
  }

  /**
   * Add submit handler.
   *
   * @inheritDoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_input_values = $form_state->getUserInput();
    $config = $this->configFactory->getEditable('admin_content_notification.settings');
    $config->set('admin_content_notification_node_types', $user_input_values['admin_content_notification_node_types']);
    $config->set('admin_content_notification_email', $user_input_values['admin_content_notification_email']);
    $config->set('admin_content_notification_email_subject', $user_input_values['admin_content_notification_email_subject']);
    $config->set('admin_content_notification_email_body', $user_input_values['admin_content_notification_email_body']);
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
